import request from '@/utils/request'
const baseUrl = import.meta.env.VITE_APP_BASE_API

// 查询提醒邮件配置文件列表
export function listEmail(query) {
  return request({
    url: baseUrl + '/business/email/list',
    method: 'get',
    params: query
  })
}

// 查询提醒邮件配置文件详细
export function getEmail(id) {
  return request({
    url: baseUrl + '/business/email/' + id,
    method: 'get'
  })
}

// 新增提醒邮件配置文件
export function addEmail(data) {
  return request({
    url: baseUrl + '/business/email',
    method: 'post',
    data: data
  })
}

// 修改提醒邮件配置文件
export function updateEmail(data) {
  return request({
    url: baseUrl + '/business/email',
    method: 'put',
    data: data
  })
}

// 删除提醒邮件配置文件
export function delEmail(id) {
  return request({
    url: baseUrl + '/business/email/' + id,
    method: 'delete'
  })
}
